{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for ISO C++.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/isocpp.xml and 'make bootstrap'.
module Skylighting.Syntax.Isocpp (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for ISO C++.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nisocpp.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIsocpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInMacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__VA_ARGS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__VA_OPT__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStdMacros\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_DEFAULT_NEW_ALIGNMENT__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_STRICT_POINTER_SAFETY__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDCPP_THREADS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI__STDC_HOSTED__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDC_ISO_10646__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN__STDC_MB_MIGHT_NEQ_WC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE__STDC_VERSION__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__STDC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__TIME__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__cplusplus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__func__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__has_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3__has_cpp_attribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2carries_dependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeprecated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfallthrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnodiscard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaybe_unused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlikely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunlikely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1no_unique_address\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bco_await\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tco_return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bco_yield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTauto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconsteval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconstinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconstexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconst_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdecltype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdynamic_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexplicit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfriend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anullptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreinterpret_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsizeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstatic_assert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstatic_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btypename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKand_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcompl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnot_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQor_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxor_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brequires\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmodifiers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fthread_local\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelifdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\belifndef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQendif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcmakedefine01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcmakedefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2preprocessorDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcmakedefine01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcmakedefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1preprocessorOther\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achar8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awchar_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tptrdiff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsig_atomic_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwint_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ava_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpos_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtime_t\NUL\NUL\NUL\NUL\NUL\NUL\NULQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*(?=.)|\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreprocessorCmd\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\DLE\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2carries_dependency\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeprecated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfallthrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlikely\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaybe_unused\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1no_unique_address\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnodiscard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunlikely\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH]]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT:>:>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB!#%&()*+-./:<=>?[]^{|}~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttributeNamespace\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DetectGccAttributes\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4[A-Z][A-Z0-9_]{2,}\\b\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttributeNamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2AttributeNamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSDetectNamespaceGccAttributes\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH##\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKChar16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKChar16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULB\\\\(?:[tnvbrfa'\"\\\\?]|[0-7]{1,3}|x[0-9A-Fa-f]{1,4}|u[0-9A-Fa-f]{4})|\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleChar\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKChar32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKChar32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULR\\\\(?:[tnvbrfa'\"\\\\?]|[0-7]{1,3}|x[0-9A-Fa-f]{1,8}|u[0-9A-Fa-f]{4}|U[0-9A-Fa-f]{8})|\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleChar\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChar8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChar8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\f\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleChar\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCharPrefix16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCharPrefix16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKChar16\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCharPrefix32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCharPrefix32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKChar32\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCharPrefix8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCharPrefix8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChar8\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckUDLOperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckUDLOperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\"\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLOperatorName\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGNUMacros\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIn Define\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH::\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t !#%&()*+,-./:;<=>?[]^{|}~\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DispatchIdentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DispatchIdentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%2\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%4\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%3\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%5\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchNamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchNamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStandard Classes\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%2\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBoost Stuff\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DispatchNamespacePP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DispatchNamespacePP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStandard Classes In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%2\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Boost Stuff In PP\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindSingleChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharClose\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBFL_bdfhilms\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FloatSuffixPattern\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FloatSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FloatSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL_\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$[fF](?:16|32|64|128)?|[lL]|bf16|BF16\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS(?:i[fl]?|min|[mun]?s|[hd])\\b\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIdentifierError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIdentifierError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t.[^\\s()]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIn Define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIn Define\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\DLE\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2!#%&()*+-:=>]^{|}~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH[[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT<:<:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAttribute In PP\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\.?\\d\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,;\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN!%&()*+-./:<=>?[]^{|}~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\"'LRUu\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSelectStringPP\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDetectGccExtensionsInPP\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL5(std::)|(boost::|BOOST_)|details?::|aux::|internals::\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DispatchNamespacePP\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__VA_ARGS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__VA_OPT__\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$@\\`\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b[^%){}]+\SOH\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL%[-+ #0]*+(?:[0-9]++|\\*)?(?:\\.(?:[0-9]++|\\*))?(?:(?:hh|ll|[hljzt]|wf?(?:8|16|32|64))?[dioxXubn]|(?:DD|[lLHD])?[fFeEaAgG]|l?[cs]|[p%])|\\{\\{|\\}\\}|\\{[0-9]*(?::(?:[^{}]?[<>^])?[-+ #0]*(?:[0-9]+|\\{[0-9]*\\})?(?:\\.(?:[0-9]+|\\{[0-9]*\\}))?L?[sbBcdoxXaAeEfFgGp]?)?\\}\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT)%1\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\"\"\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\ETX<>\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE(?:#|%\\:|\\?\\?=)|\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Inscoped AfterHash\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Inscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Inscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%(?:#|%\\:|\\?\\?=)\\s*el(?:se|if(n?def)?)\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutscoped 2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(?:#|%\\:|\\?\\?=)\\s*endif\\b\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIntStartsWith0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIntStartsWith0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)0[xX](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]++)*+)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB0[Bb][01](?:'?[01]++)*+\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE0(?:'?[0-7]++)++\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\NUL0\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLUZ_dhilmnsuyz\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntSuffixPattern\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL_\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+([Uu](LL?|ll?|[Zz])?|(LL?|ll?|[Zz])[Uu]?)\\b\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS(?:i[fl]?|min|[mun]?s|[hyd])\\b\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL0\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIntStartsWith0\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:[0-9](?:'?[0-9]++)*+)\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE[._0-9A-Za-z']++\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInternalsNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1InternalsNS In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH##\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^\\\\]+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO!&()*+-:=>]^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,;\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH%>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH[[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT<:<:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL#\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\SOH%:\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX??=\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAfterHash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\.?[0-9]\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN!%&()*+-./:<=>?[]^{|}~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\"'LRUu\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSelectString\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DetectGccExtensions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL5(std::)|(boost::|BOOST_)|details?::|aux::|internals::\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchNamespace\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$@`\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDoxygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 1\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComment 2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a//BEGIN\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ//END\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\182\\.(?:[0-9](?:'?[0-9]++)*+)(?:[eE][+-]?(?:[0-9](?:'?[0-9]++)*+))?|0[xX](?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]++)*+)(?:[pP][-+]?(?:[0-9](?:'?[0-9]++)*+))?|(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]++)*+)(?:(?:[pP][-+]?(?:[0-9](?:'?[0-9]++)*+))|\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f]++)*+)?(?:[pP][-+]?(?:[0-9](?:'?[0-9]++)*+))?))|(?:[0-9](?:'?[0-9]++)*+)(?:(?:[eE][+-]?(?:[0-9](?:'?[0-9]++)*+))|\\.(?:[0-9](?:'?[0-9]++)*+)?(?:[eE][+-]?(?:[0-9](?:'?[0-9]++)*+))?)\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFloatSuffix\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH0\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntSuffix\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInteger\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f'.0123456789\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANNumericUserSuffixPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v_[eEpP][+-]\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2NumericSuffixError\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOutscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOutscoped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE(?:#|%\\:|\\?\\?=)|\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Outscoped AfterHash\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutscoped 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vOutscoped 2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*endif|\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Outscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3Outscoped AfterHash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(?:#|%\\:|\\?\\?=)\\s*endif\\b\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*else\\b\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4(?:#|%\\:|\\?\\?=)\\s*if\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULe(?:#|%\\:|\\?\\?=)\\s*elif\\s+(?:1|true)\\s*(\\|\\|([^/]|/[^*/])+)?($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULQ(?:#|%\\:|\\?\\?=)\\s*elif\\s+(?:0|false)\\s*($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*elif\\b\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2(?:#|%\\:|\\?\\?=)\\s*\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped Common\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK(?:#|%\\:|\\?\\?=)\\s*if|\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\SO\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK(?:#|%\\:|\\?\\?=)\\s*if|\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOutscoped intern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$(?:#|%\\:|\\?\\?=)\\s*el(se|if(n?def)?)|\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(?:#|%\\:|\\?\\?=)\\s*endif|\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_DEFAULT_NEW_ALIGNMENT__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_STRICT_POINTER_SAFETY__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDCPP_THREADS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI__STDC_HOSTED__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDC_ISO_10646__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN__STDC_MB_MIGHT_NEQ_WC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE__STDC_VERSION__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__STDC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__TIME__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__cplusplus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__func__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3__has_cpp_attribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__has_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rGCCExtensions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGNUMacros\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreprocessorCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPreprocessorCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQifdef\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKifndef\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQendif\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelifdef\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\belifndef\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcmakedefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcmakedefine01\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdefine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDefine\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awarning\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finclude_next\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aInclude\b\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPreprocessorEndOfLineSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPreprocessorIf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULR\\w+\\s+(?:1|true)\\s*(\\|\\|([^/]|/[^*/])+)?($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bInscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\\w+\\s+(?:0|false)\\s*($|(?=(/\\*([^*]|\\*[^/])*\\*/\\s*)?(//.*)?$))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tOutscoped\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\w+\\s+(?=[^\\s])\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PreprocessorIfDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\w+\\s+([_A-Za-z][A-Za-z0-9]*\\s*|(?=//|/\\*))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLineError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ8LRUu\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\"([\\x21-\\x27\\x2A-\\x5B\\x5D-\\x7E]{0,16})\\(\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vInRawString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\"(\\s+|\\w+\\s*|\"|[^\\s\\w]+)?\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegion Marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectCharPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectCharPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOHu8\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCharPrefix8\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLu\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCharPrefix16\NULU\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCharPrefix32\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSelectString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSelectString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQChar8\SOHU\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SelectStringPrefix\SOHu\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SelectStringPrefix\SOHL\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SelectStringPrefix\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu8\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SelectStringPrefix\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXR\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuR\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXUR\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLR\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTu8R\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\SOHU'\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectCharPrefix\SOHu'\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectCharPrefix\SOHL'\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectCharPrefix\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu8'\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESelectCharPrefix\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achar8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpos_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tptrdiff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsig_atomic_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtime_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ava_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awchar_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwint_t\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULn([a-zA-Z][a-zA-Z0-9_]*__\\b)|([a-z][a-zA-Z0-9_]*_\\b)|([A-Z][A-Z0-9_]{2,}\\b)|([a-zA-Z][a-zA-Z0-9_]*_t(?:ype)?\\b)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DispatchIdentifier\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSelectStringPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSelectStringPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSelectString\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SelectStringPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SelectStringPrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOHu8\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStringPrefix8\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLu\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringPrefix16\NULU\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringPrefix32\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStandard Classes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEStandard Classes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStandard Classes In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNStandard Classes In PP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInPreprocessor\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH##\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDetectNSEnd\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\x\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIString16EscapeX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIString16EscapeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIString16EscapeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\x[0-9A-Fa-f]{1,4}\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKstring special char x\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\x\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIString32EscapeX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIString32EscapeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIString32EscapeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\x[0-9A-Fa-f]{1,8}\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKstring special char x\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\x\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString8EscapeX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString8EscapeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOString8EscapeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\f\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKstring special char x\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStringNoHex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI[0-9A-Fa-f]{1,}\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringPrefix16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringPrefix16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString16\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringPrefix32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringPrefix32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bString32\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStringPrefix8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rStringPrefix8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aString8\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLOperatorName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLOperatorName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_[_[:alnum:]]*\\b\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIdentifierError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLStringSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLStringSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsv\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHs\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE_[_0-9A-Za-z]*\\b\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\NUL\NUL\NUL\NUL\NUL\NUL\NUL!match comments and region markers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSMatchCommentAndRegionMarkers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmatch identifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchar32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\achar8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfpos_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tptrdiff_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsig_atomic_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assize_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtime_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\buint64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auint8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_fast64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fuint_fast8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least16_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least32_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOuint_least64_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ruint_least8_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintmax_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tuintptr_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunsigned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ava_list\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awchar_t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwint_t\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKextern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregister\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fthread_local\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_Pragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_DEFAULT_NEW_ALIGNMENT__\NUL\NUL\NUL\NUL\NUL\NUL\NUL __STDCPP_STRICT_POINTER_SAFETY__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDCPP_THREADS__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI__STDC_HOSTED__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2__STDC_ISO_10646__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN__STDC_MB_MIGHT_NEQ_WC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE__STDC_VERSION__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__STDC__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__TIME__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__cplusplus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__func__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3__has_cpp_attribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r__has_include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\182((?:_[a-zA-Z0-9_]+|[a-zA-Z][a-zA-Z0-9_]*__\\b))|((?:m_[a-zA-Z0-9_]+|[a-z][a-zA-Z0-9_]*_\\b))|([A-Z][A-Z0-9_]{2,}\\b)|([a-zA-Z][a-zA-Z0-9_]*_t(?:ype)?\\b)|(g_[a-zA-Z0-9_]+)|s_[a-zA-Z0-9_]\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DispatchIdentifier\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmatch keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECheckUDLOperator\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bco_await\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tco_return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bco_yield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQthrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKand_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTauto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbitand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbitor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcompl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconst_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconsteval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconstexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconstinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdecltype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdynamic_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexplicit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfriend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnoexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnot_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anullptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQor_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotected\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreinterpret_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brequires\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsizeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstatic_assert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstatic_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypedef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btypename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avirtual\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxor_eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2string normal char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIUDLStringSuffix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[^%\\\\\"{}]+\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3string special char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\f\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOHO\\\\(?:u[0-9A-Fa-f]{4}|U[0-9A-Fa-f]{8}|u{[0-9A-Fa-f]+}|o{[0-7]+}|N{[- A-Z0-9]+})|%[-+ #0]*+(?:[0-9]++|\\*)?(?:\\.(?:[0-9]++|\\*))?(?:(?:hh|ll|[hljzt]|wf?(?:8|16|32|64))?[dioxXubn]|(?:DD|[lLHD])?[fFeEaAgG]|l?[cs]|[p%])|\\{\\{|\\}\\}|\\{[0-9]*(?::(?:[^{}]?[<>^])?[-+ #0]*(?:[0-9]+|\\{[0-9]*\\})?(?:\\.(?:[0-9]+|\\{[0-9]*\\}))?L?[sbBcdoxXaAeEfFgGp]?)?\\}\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%{}\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\\\\(?:u{([0-9A-Fa-f]+|})?|u[0-9A-Fa-f]{0,3}|U[0-9A-Fa-f]{0,7}|o{([0-7]+|})?|N{([- A-Z0-9]+|})?|.)\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKstring special char x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKstring special char x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aISO C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\\\x{[0-9A-Fa-f]+}\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\\\x({([0-9A-Fa-f]+|})?)?\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USAlex Turbov (i.zaufi@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.c++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.cc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.cu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.h\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.hh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.H\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.h++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.hxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.hpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.hcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cuh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.inl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ino\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.moc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.mpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ixx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.cppm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.cxxm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.c++m\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ccm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMain"
